Documentation
¶
Overview ¶
Package docs provides the content of github pages at https://gregoryv.github.io/draw/
Index ¶
- func AllShapes() *design.Diagram
- func ExampleActivityDiagram() *design.ActivityDiagram
- func ExampleClassDiagram() *design.ClassDiagram
- func ExampleDiagram() *design.Diagram
- func ExampleGanttChart() *design.GanttChart
- func ExampleSequenceDiagram() *design.SequenceDiagram
- func ExampleSmallClassDiagram() *design.ClassDiagram
- func LoadFile(filename string, span ...int) *Element
- func NewProjectArticle() *Element
- func NewProjectsPage() *Page
- func Theme() *CSS
- type Door
- type House
- type Part
- type Window
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExampleActivityDiagram ¶
func ExampleActivityDiagram() *design.ActivityDiagram
func ExampleClassDiagram ¶
func ExampleClassDiagram() *design.ClassDiagram
func ExampleDiagram ¶
func ExampleGanttChart ¶
func ExampleGanttChart() *design.GanttChart
func ExampleSequenceDiagram ¶
func ExampleSequenceDiagram() *design.SequenceDiagram
func ExampleSmallClassDiagram ¶
func ExampleSmallClassDiagram() *design.ClassDiagram
func LoadFile ¶
LoadFile returns a pre web element wrapping the contents from the given file. If to == -1 all lines to the end of file are returned.
func NewProjectArticle ¶
func NewProjectArticle() *Element
func NewProjectsPage ¶
func NewProjectsPage() *Page
Types ¶
Click to show internal directories.
Click to hide internal directories.